aboutsummaryrefslogtreecommitdiffstats
path: root/src/can/can-bus.cpp
diff options
context:
space:
mode:
authorRomain Forlot <romain.forlot@iot.bzh>2017-03-08 23:48:34 +0100
committerRomain Forlot <romain.forlot@iot.bzh>2017-03-16 17:10:40 +0100
commitbcb9bf1be8a854f9a9a5b2025ed9ee03b084ea44 (patch)
tree309744ddffe46fc71bb00d66added4fb58e8f927 /src/can/can-bus.cpp
parentb8e9588a9fb64b2e7ef7859ae0ab147c0c92ddda (diff)
Change all old struct name to the new class.
Change-Id: I8aa4430117c401182ef458a06a2aeb08957db1bb Signed-off-by: Romain Forlot <romain.forlot@iot.bzh>
Diffstat (limited to 'src/can/can-bus.cpp')
-rw-r--r--src/can/can-bus.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/can/can-bus.cpp b/src/can/can-bus.cpp
index 77211327..4416452b 100644
--- a/src/can/can-bus.cpp
+++ b/src/can/can-bus.cpp
@@ -66,7 +66,7 @@ can_bus_t::can_bus_t(int conf_file)
void can_bus_t::can_decode_message()
{
can_message_t can_message;
- std::vector <CanSignal*> signals;
+ std::vector <can_signal_t*> signals;
openxc_VehicleMessage vehicle_message;
openxc_DynamicField search_key, decoded_message;
@@ -78,7 +78,7 @@ void can_bus_t::can_decode_message()
new_can_message_cv_.wait(can_message_lock);
can_message = next_can_message();
/* First we have to found which CanSignal it is */
search_key = build_DynamicField((double)can_message.get_id());
signals.clear();
find_can_signals(search_key, signals);
@@ -78,7 +78,7 @@ void can_bus_t::can_decode_message()
new_can_message_cv_.wait(can_message_lock);
can_message = next_can_message();
- /* First we have to found which CanSignal it is */
+ /* First we have to found which can_signal_t it is */
search_key = build_DynamicField((double)can_message.get_id());
signals.clear();